@@ -476,9 +476,9 @@ Queue to put job in, defaults to C<default>.
   my $bool = $backend->fail_job(
     $job_id, $retries, {whatever => 'Something went wrong!'});
 
-Transition from C<active> to C<failed> state, and if there are attempts
-remaining, transition back to C<inactive> with a delay based on
-L<Minion/"backoff">.
+Transition from C<active> to C<failed> state with or without a result, and if
+there are attempts remaining, transition back to C<inactive> with a delay based
+on L<Minion/"backoff">.
 
 =head2 finish_job
 
@@ -487,7 +487,7 @@ L<Minion/"backoff">.
   my $bool = $backend->finish_job(
     $job_id, $retries, {whatever => 'All went well!'});
 
-Transition from C<active> to C<finished> state.
+Transition from C<active> to C<finished> state with or without a result.
 
 =head2 history
 
@@ -515,6 +515,9 @@ Hourly counts for processed jobs from the past day.
 
 Returns the information about jobs in batches.
 
+  # Get the total number of results (without limit)
+  my $num = $backend->list_jobs(0, 100, {queues => ['important']})->{total};
+
   # Check job state
   my $results = $backend->list_jobs(0, 1, {ids => [$job_id]});
   my $state = $results->{jobs}[0]{state};
@@ -593,6 +596,12 @@ Epoch time job was delayed to.
 
 Epoch time job was finished.
 
+=item id
+
+  id => 10025
+
+Job id.
+
 =item notes
 
   notes => {foo => 'bar', baz => [1, 2, 3]}
@@ -668,6 +677,9 @@ Id of worker that is processing the job.
 
 Returns information about locks in batches.
 
+  # Get the total number of results (without limit)
+  my $num = $backend->list_locks(0, 100, {names => ['bar']})->{total};
+
   # Check expiration time
   my $results = $backend->list_locks(0, 1, {names => ['foo']});
   my $expires = $results->{locks}[0]{expires};
@@ -709,6 +721,9 @@ Lock name.
 
 Returns information about workers in batches.
 
+  # Get the total number of results (without limit)
+  my $num = $backend->list_workers(0, 100)->{total};
+
   # Check worker host
   my $results = $backend->list_workers(0, 1, {ids => [$worker_id]});
   my $host    = $results->{workers}[0]{host};
@@ -729,6 +744,12 @@ These fields are currently available:
 
 =over 2
 
+=item id
+
+  id => 22
+
+Worker id.
+
 =item host
 
   host => 'localhost'
@@ -980,7 +1001,7 @@ Unregister worker.
 
 =head1 SEE ALSO
 
-L<Minion>, L<Mojolicious::Guides>, L<http://mojolicious.org>.
+L<Minion>, L<Mojolicious::Guides>, L<https://mojolicious.org>.
 
 =cut
 
